( cd opt/kde/share/doc/HTML/es/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ark ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ktuberling ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/amor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/karm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdvi ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kgpg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmag ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmid ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmix ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kodo ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kolf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpdf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/korn ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kscd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksim ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/lisa ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kalzium ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/katomic ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksysguard ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kbounce ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdelirc/kcmlirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdelirc/irkick ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kbattleship ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kaboodle ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/khangman ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kfloppy ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/khexedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/khexedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpercentage ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kandy ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcalc ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdesu ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcron ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kfind ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kiten ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kiten ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kjots ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kjots ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmail ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmoon ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/knode ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kooka ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksame ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ktnef ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ktnef ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksysv ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ktron ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kuser ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kview ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kwin4 ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/lskat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/klipper ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmousetool ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kompare ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kontact ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/konsole ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/konsolekalendar ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpackage ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kshisen ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksirtet ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/konquest ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kverbos ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kwallet ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kweather ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kwuftpd ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/flashkard ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/flashkard ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/aktion ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/aktion ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kxconfig ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kxconfig ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/es/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/es/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kxmlrpcd ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kbabel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kalarm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kamera ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kasteroids ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/keduca ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kgamma ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kicker ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/klines ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmines ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmouth ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/knotes ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpaint ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kopete ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpilot ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpoker ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kruler ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksnake ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kspell ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ktimer ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ktouch ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/megami ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/megami ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kreversi ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/noatun ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kblackbox ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kcharselect ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/quanta ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kuickshow ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kommander ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kommander ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kiconedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/klettres ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kghostview ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/klickety ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kleopatra ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kenolaba ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kwatchgnupg ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kworldclock ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/ksokoban ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kteatime ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kmathtool ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/korganizer ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/atlantik ; ln -sf /opt/kde/share/doc/HTML/es/common common )
